This dataset, centenarian_df, is a data frame containing the number of deaths at each year from 1963 to 1980 for Japanese male centenarians. The data is based on Table 2 of Emura and Murotani (2015), and also references the original work of Sibuya & Hanayama (2004).
data(centenarian_df)A data frame with 21 observations and 19 variables:
Age or identifier (numeric)
Number of deaths in 1963 (integer)
Number of deaths in 1964 (integer)
Number of deaths in 1965 (integer)
Number of deaths in 1966 (integer)
Number of deaths in 1967 (integer)
Number of deaths in 1968 (integer)
Number of deaths in 1969 (integer)
Number of deaths in 1970 (integer)
Number of deaths in 1971 (integer)
Number of deaths in 1972 (integer)
Number of deaths in 1973 (integer)
Number of deaths in 1974 (integer)
Number of deaths in 1975 (integer)
Number of deaths in 1976 (integer)
Number of deaths in 1977 (integer)
Number of deaths in 1978 (integer)
Number of deaths in 1979 (integer)
Number of deaths in 1980 (integer)
The dataset name has been kept as 'centenarian_df' to avoid confusion with other datasets in the R ecosystem. This naming convention helps distinguish this dataset as part of the JapanAPIs package and assists users in identifying its specific characteristics. The suffix 'df' indicates that the dataset is a data frame. The original content has not been modified in any way.