Get Hospital Beds per 1,000 People in Japan from World Bank
Source:R/get_japan_hospital_beds.R
get_japan_hospital_beds.RdRetrieves data on the number of hospital beds per 1,000 people in Japan
from 2010 to 2022 using the World Bank Open Data API.
The indicator used is SH.MED.BEDS.ZS.
World Bank Open Data API: https://data.worldbank.org/indicator/SH.MED.BEDS.ZS
Value
A tibble with the following columns, or NULL if the API is unavailable:
indicator: Indicator name (e.g., "Hospital beds (per 1,000 people)")country: Country name ("Japan")year: Year of the data (integer)value: Hospital beds per 1,000 people (numeric)
Details
This function sends a GET request to the World Bank API.
If the API request fails or returns an error status code,
the function returns NULL with an informative message.
Examples
# \donttest{
# Requires internet connection
result <- get_japan_hospital_beds()
if (!is.null(result)) {
print(result)
}
#> # A tibble: 13 × 4
#> indicator country year value
#> <chr> <chr> <int> <dbl>
#> 1 Hospital beds (per 1,000 people) Japan 2022 NA
#> 2 Hospital beds (per 1,000 people) Japan 2021 NA
#> 3 Hospital beds (per 1,000 people) Japan 2020 12.7
#> 4 Hospital beds (per 1,000 people) Japan 2019 12.9
#> 5 Hospital beds (per 1,000 people) Japan 2018 13
#> 6 Hospital beds (per 1,000 people) Japan 2017 13.0
#> 7 Hospital beds (per 1,000 people) Japan 2016 13.1
#> 8 Hospital beds (per 1,000 people) Japan 2015 13.2
#> 9 Hospital beds (per 1,000 people) Japan 2014 13.2
#> 10 Hospital beds (per 1,000 people) Japan 2013 13.3
#> 11 Hospital beds (per 1,000 people) Japan 2012 13.3
#> 12 Hospital beds (per 1,000 people) Japan 2011 13.4
#> 13 Hospital beds (per 1,000 people) Japan 2010 13.5
# }