Get Japan's Literacy Rate (Age 15+) from World Bank
Source:R/get_japan_literacy_rate.R
get_japan_literacy_rate.RdRetrieves Japan's literacy rate for adults aged 15 and above,
expressed as a percentage, for the years 2010 to 2022 using the World Bank Open Data API.
The indicator used is SE.ADT.LITR.ZS.
World Bank Open Data API: https://data.worldbank.org/indicator/SE.ADT.LITR.ZS
Value
A tibble with the following columns, or NULL if the API is unavailable:
indicator: Indicator name (e.g., "Literacy rate, adult total (country: Country name ("Japan")year: Year of the data (integer)value: Literacy rate as numeric percentage
Details
The function sends a GET request to the World Bank API.
If the API request fails or returns an error status code, the function returns NULL with an informative message.
Note
Requires internet connection. The data is retrieved in real time from the World Bank API. Note that literacy rate data for Japan may not be available for all years in the World Bank database.
Examples
# \donttest{
# Requires internet connection
result <- get_japan_literacy_rate()
if (!is.null(result)) {
print(result)
}
#> # A tibble: 13 × 4
#> indicator country year value
#> <chr> <chr> <int> <lgl>
#> 1 Literacy rate, adult total (% of people ages 15 and abov… Japan 2022 NA
#> 2 Literacy rate, adult total (% of people ages 15 and abov… Japan 2021 NA
#> 3 Literacy rate, adult total (% of people ages 15 and abov… Japan 2020 NA
#> 4 Literacy rate, adult total (% of people ages 15 and abov… Japan 2019 NA
#> 5 Literacy rate, adult total (% of people ages 15 and abov… Japan 2018 NA
#> 6 Literacy rate, adult total (% of people ages 15 and abov… Japan 2017 NA
#> 7 Literacy rate, adult total (% of people ages 15 and abov… Japan 2016 NA
#> 8 Literacy rate, adult total (% of people ages 15 and abov… Japan 2015 NA
#> 9 Literacy rate, adult total (% of people ages 15 and abov… Japan 2014 NA
#> 10 Literacy rate, adult total (% of people ages 15 and abov… Japan 2013 NA
#> 11 Literacy rate, adult total (% of people ages 15 and abov… Japan 2012 NA
#> 12 Literacy rate, adult total (% of people ages 15 and abov… Japan 2011 NA
#> 13 Literacy rate, adult total (% of people ages 15 and abov… Japan 2010 NA
# }